package com.doc.scanner.service.impl;

import java.util.List;
        import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.doc.scanner.mapper.ScannerInfoMapper;
import com.doc.scanner.domain.ScannerInfo;
import com.doc.scanner.service.IScannerInfoService;
import javax.annotation.Resource;

/**
 * 扫描仪管理Service业务层处理
 *
 * @author wukai
 * @date 2023-11-28
 */
@Service
public class ScannerInfoServiceImpl implements IScannerInfoService {
    @Resource
    private ScannerInfoMapper scannerInfoMapper;

    /**
     * 查询扫描仪管理
     *
     * @param scannerId 扫描仪管理主键
     * @return 扫描仪管理
     */
    @Override
    public ScannerInfo selectScannerInfoByScannerId(Long scannerId) {
        return scannerInfoMapper.selectScannerInfoByScannerId(scannerId);
    }

    /**
     * 查询扫描仪管理列表
     *
     * @param scannerInfo 扫描仪管理
     * @return 扫描仪管理
     */
    @Override
    public List<ScannerInfo> selectScannerInfoList(ScannerInfo scannerInfo) {
        return scannerInfoMapper.selectScannerInfoList(scannerInfo);
    }

    /**
     * 新增扫描仪管理
     *
     * @param scannerInfo 扫描仪管理
     * @return 结果
     */
    @Override
    public int insertScannerInfo(ScannerInfo scannerInfo) {
                scannerInfo.setCreateTime(DateUtils.getNowDate());
            return scannerInfoMapper.insertScannerInfo(scannerInfo);
    }

    /**
     * 修改扫描仪管理
     *
     * @param scannerInfo 扫描仪管理
     * @return 结果
     */
    @Override
    public int updateScannerInfo(ScannerInfo scannerInfo) {
                scannerInfo.setUpdateTime(DateUtils.getNowDate());
        return scannerInfoMapper.updateScannerInfo(scannerInfo);
    }

    /**
     * 批量删除扫描仪管理
     *
     * @param scannerIds 需要删除的扫描仪管理主键
     * @return 结果
     */
    @Override
    public int deleteScannerInfoByScannerIds(Long[] scannerIds) {
        return scannerInfoMapper.deleteScannerInfoByScannerIds(scannerIds);
    }

    /**
     * 删除扫描仪管理信息
     *
     * @param scannerId 扫描仪管理主键
     * @return 结果
     */
    @Override
    public int deleteScannerInfoByScannerId(Long scannerId) {
        return scannerInfoMapper.deleteScannerInfoByScannerId(scannerId);
    }
}
